@@ -23,6 +23,13 @@ def get(index, items, default=False):
         Log.d(f"Failed to get index. error=[ {e} ]")
         return default
 
+def get_random(items, default=False):
+    count = len(items)
+    if count <= 0:
+        return default
+    ran_index  =random.randint(0, count)
+    return get(ran_index, items, default)
+
 def find_str(term: str, items, default=False):
     """ Safely get index """
     # TODO: Build this to go DEEP!
